@@ -45,15 +45,15 @@ time_t		 get_monotime(time_t);
 char		*fmt_peer(const char *, const struct bgpd_addr *, int);
 const char	*fmt_timeframe(time_t);
 const char	*fmt_monotime(time_t);
-const char	*fmt_fib_flags(u_int16_t);
-const char	*fmt_origin(u_int8_t, int);
-const char	*fmt_flags(u_int8_t, int);
-const char	*fmt_ovs(u_int8_t, int);
+const char	*fmt_fib_flags(uint16_t);
+const char	*fmt_origin(uint8_t, int);
+const char	*fmt_flags(uint8_t, int);
+const char	*fmt_ovs(uint8_t, int);
 const char	*fmt_auth_method(enum auth_method);
 const char	*fmt_mem(long long);
-const char	*fmt_errstr(u_int8_t, u_int8_t);
-const char	*fmt_attr(u_int8_t, int);
-const char	*fmt_community(u_int16_t, u_int16_t);
-const char	*fmt_large_community(u_int32_t, u_int32_t, u_int32_t);
-const char	*fmt_ext_community(u_int8_t *);
+const char	*fmt_errstr(uint8_t, uint8_t);
+const char	*fmt_attr(uint8_t, int);
+const char	*fmt_community(uint16_t, uint16_t);
+const char	*fmt_large_community(uint32_t, uint32_t, uint32_t);
+const char	*fmt_ext_community(uint8_t *);
 const char	*fmt_set_type(struct ctl_show_set *);
