@@ -1,4 +1,4 @@
-/*	$OpenBSD: rtr_proto.c,v 1.4 2021/08/02 16:42:13 claudio Exp $ */
+/*	$OpenBSD: rtr_proto.c,v 1.6 2022/03/08 13:02:42 tb Exp $ */
 
 /*
  * Copyright (c) 2020 Claudio Jeker <claudio@openbsd.org>
@@ -189,7 +189,7 @@ log_rtr_type(enum rtr_pdu_type type)
 };
 
 static struct ibuf *
-rtr_newmsg(enum rtr_pdu_type type, uint32_t len, u_int16_t session_id)
+rtr_newmsg(enum rtr_pdu_type type, uint32_t len, uint16_t session_id)
 {
 	struct ibuf *buf;
 	struct rtr_header rh;
@@ -442,13 +442,6 @@ rtr_parse_ipv4_prefix(struct rtr_session *rs, uint8_t *buf, size_t len)
 	}
 
 	memcpy(&ip4, buf + sizeof(struct rtr_header), sizeof(ip4));
-
-	if ((roa = calloc(1, sizeof(*roa))) == NULL) {
-		log_warn("rtr %s: received %s",
-		    log_rtr(rs), log_rtr_type(IPV4_PREFIX));
-		rtr_send_error(rs, INTERNAL_ERROR, "out of memory", NULL, 0);
-		return -1;
-	}
 	if (ip4.prefixlen > 32 || ip4.maxlen > 32 ||
 	    ip4.prefixlen > ip4.maxlen) {
 		log_warnx("rtr: %s: received %s: bad prefixlen / maxlen",
@@ -457,6 +450,13 @@ rtr_parse_ipv4_prefix(struct rtr_session *rs, uint8_t *buf, size_t len)
 		    buf, len);
 		return -1;
 	}
+
+	if ((roa = calloc(1, sizeof(*roa))) == NULL) {
+		log_warn("rtr %s: received %s",
+		    log_rtr(rs), log_rtr_type(IPV4_PREFIX));
+		rtr_send_error(rs, INTERNAL_ERROR, "out of memory", NULL, 0);
+		return -1;
+	}
 	roa->aid = AID_INET;
 	roa->prefixlen = ip4.prefixlen;
 	roa->maxlen = ip4.maxlen;
@@ -511,13 +511,6 @@ rtr_parse_ipv6_prefix(struct rtr_session *rs, uint8_t *buf, size_t len)
 	}
 
 	memcpy(&ip6, buf + sizeof(struct rtr_header), sizeof(ip6));
-
-	if ((roa = calloc(1, sizeof(*roa))) == NULL) {
-		log_warn("rtr %s: received %s",
-		    log_rtr(rs), log_rtr_type(IPV6_PREFIX));
-		rtr_send_error(rs, INTERNAL_ERROR, "out of memory", NULL, 0);
-		return -1;
-	}
 	if (ip6.prefixlen > 128 || ip6.maxlen > 128 ||
 	    ip6.prefixlen > ip6.maxlen) {
 		log_warnx("rtr: %s: received %s: bad prefixlen / maxlen",
@@ -526,6 +519,13 @@ rtr_parse_ipv6_prefix(struct rtr_session *rs, uint8_t *buf, size_t len)
 		    buf, len);
 		return -1;
 	}
+
+	if ((roa = calloc(1, sizeof(*roa))) == NULL) {
+		log_warn("rtr %s: received %s",
+		    log_rtr(rs), log_rtr_type(IPV6_PREFIX));
+		rtr_send_error(rs, INTERNAL_ERROR, "out of memory", NULL, 0);
+		return -1;
+	}
 	roa->aid = AID_INET6;
 	roa->prefixlen = ip6.prefixlen;
 	roa->maxlen = ip6.maxlen;
