@@ -1,4 +1,4 @@
-/*	$OpenBSD: session.c,v 1.424 2021/09/03 07:48:24 claudio Exp $ */
+/*	$OpenBSD: session.c,v 1.427 2022/02/23 11:20:35 claudio Exp $ */
 
 /*
  * Copyright (c) 2003, 2004, 2005 Henning Brauer <henning@openbsd.org>
@@ -66,38 +66,38 @@ void	session_accept(int);
 int	session_connect(struct peer *);
 void	session_tcp_established(struct peer *);
 void	session_capa_ann_none(struct peer *);
-int	session_capa_add(struct ibuf *, u_int8_t, u_int8_t);
-int	session_capa_add_mp(struct ibuf *, u_int8_t);
-int	session_capa_add_afi(struct peer *, struct ibuf *, u_int8_t, u_int8_t);
-struct bgp_msg	*session_newmsg(enum msg_type, u_int16_t);
+int	session_capa_add(struct ibuf *, uint8_t, uint8_t);
+int	session_capa_add_mp(struct ibuf *, uint8_t);
+int	session_capa_add_afi(struct peer *, struct ibuf *, uint8_t, uint8_t);
+struct bgp_msg	*session_newmsg(enum msg_type, uint16_t);
 int	session_sendmsg(struct bgp_msg *, struct peer *);
 void	session_open(struct peer *);
 void	session_keepalive(struct peer *);
-void	session_update(u_int32_t, void *, size_t);
-void	session_notification(struct peer *, u_int8_t, u_int8_t, void *,
+void	session_update(uint32_t, void *, size_t);
+void	session_notification(struct peer *, uint8_t, uint8_t, void *,
 	    ssize_t);
-void	session_rrefresh(struct peer *, u_int8_t, u_int8_t);
+void	session_rrefresh(struct peer *, uint8_t, uint8_t);
 int	session_graceful_restart(struct peer *);
 int	session_graceful_stop(struct peer *);
 int	session_dispatch_msg(struct pollfd *, struct peer *);
 void	session_process_msg(struct peer *);
-int	parse_header(struct peer *, u_char *, u_int16_t *, u_int8_t *);
+int	parse_header(struct peer *, u_char *, uint16_t *, uint8_t *);
 int	parse_open(struct peer *);
 int	parse_update(struct peer *);
 int	parse_rrefresh(struct peer *);
 int	parse_notification(struct peer *);
-int	parse_capabilities(struct peer *, u_char *, u_int16_t, u_int32_t *);
+int	parse_capabilities(struct peer *, u_char *, uint16_t, uint32_t *);
 int	capa_neg_calc(struct peer *);
 void	session_dispatch_imsg(struct imsgbuf *, int, u_int *);
 void	session_up(struct peer *);
 void	session_down(struct peer *);
-int	imsg_rde(int, u_int32_t, void *, u_int16_t);
+int	imsg_rde(int, uint32_t, void *, uint16_t);
 void	session_demote(struct peer *, int);
 void	merge_peers(struct bgpd_config *, struct bgpd_config *);
 
 int		 la_cmp(struct listen_addr *, struct listen_addr *);
 void		 session_template_clone(struct peer *, struct sockaddr *,
-		    u_int32_t, u_int32_t);
+		    uint32_t, uint32_t);
 int		 session_match_mask(struct peer *, struct bgpd_addr *);
 
 static struct bgpd_config	*conf, *nconf;
@@ -452,9 +452,11 @@ session_main(int debug, int verbose)
 			timeout = 1;
 		if (timeout < 0)
 			timeout = 0;
-		if (poll(pfd, i, timeout * 1000) == -1)
-			if (errno != EINTR)
-				fatal("poll error");
+		if (poll(pfd, i, timeout * 1000) == -1) {
+			if (errno == EINTR)
+				continue;
+			fatal("poll error");
+		}
 
 		/*
 		 * If we previously saw fd exhaustion, we stop accept()
@@ -1099,7 +1101,7 @@ session_connect(struct peer *peer)
 		return (-1);
 	}
 
-	sa = addr2sa(&peer->conf.remote_addr, BGP_PORT, &sa_len);
+	sa = addr2sa(&peer->conf.remote_addr, peer->conf.remote_port, &sa_len);
 	if (connect(peer->fd, sa, sa_len) == -1) {
 		if (errno != EINPROGRESS) {
 			if (errno != peer->lasterr)
@@ -1138,6 +1140,7 @@ session_setup_socket(struct peer *p)
 			 * 1=direct n=multihop with ttlsec, we always use 255
 			 */
 			if (p->conf.ttlsec) {
+#ifdef IP_MINTTL
 				ttl = 256 - p->conf.distance;
 				if (setsockopt(p->fd, IPPROTO_IP, IP_MINTTL,
 				    &ttl, sizeof(ttl)) == -1) {
@@ -1147,6 +1150,10 @@ session_setup_socket(struct peer *p)
 					return (-1);
 				}
 				ttl = 255;
+#else
+				log_peer_warn(&p->conf, "OS does not support "
+				    "ttl-security for IPv4 sessions");
+#endif
 			}
 
 			if (setsockopt(p->fd, IPPROTO_IP, IP_TTL, &ttl,
@@ -1307,7 +1314,7 @@ session_capa_ann_none(struct peer *peer)
 }
 
 int
-session_capa_add(struct ibuf *opb, u_int8_t capa_code, u_int8_t capa_len)
+session_capa_add(struct ibuf *opb, uint8_t capa_code, uint8_t capa_len)
 {
 	int errs = 0;
 
@@ -1317,10 +1324,10 @@ session_capa_add(struct ibuf *opb, u_int8_t capa_code, u_int8_t capa_len)
 }
 
 int
-session_capa_add_mp(struct ibuf *buf, u_int8_t aid)
+session_capa_add_mp(struct ibuf *buf, uint8_t aid)
 {
-	u_int8_t		 safi, pad = 0;
-	u_int16_t		 afi;
+	uint8_t			 safi, pad = 0;
+	uint16_t		 afi;
 	int			 errs = 0;
 
 	if (aid2afi(aid, &afi, &safi) == -1)
@@ -1334,12 +1341,12 @@ session_capa_add_mp(struct ibuf *buf, u_int8_t aid)
 }
 
 int
-session_capa_add_afi(struct peer *p, struct ibuf *b, u_int8_t aid,
-    u_int8_t flags)
+session_capa_add_afi(struct peer *p, struct ibuf *b, uint8_t aid,
+    uint8_t flags)
 {
 	u_int		errs = 0;
-	u_int16_t	afi;
-	u_int8_t	safi;
+	uint16_t	afi;
+	uint8_t		safi;
 
 	if (aid2afi(aid, &afi, &safi)) {
 		log_warn("session_capa_add_afi: bad AID");
@@ -1355,7 +1362,7 @@ session_capa_add_afi(struct peer *p, struct ibuf *b, u_int8_t aid,
 }
 
 struct bgp_msg *
-session_newmsg(enum msg_type msgtype, u_int16_t len)
+session_newmsg(enum msg_type msgtype, uint16_t len)
 {
 	struct bgp_msg		*msg;
 	struct msg_header	 hdr;
@@ -1419,8 +1426,8 @@ session_open(struct peer *p)
 	struct bgp_msg		*buf;
 	struct ibuf		*opb;
 	struct msg_open		 msg;
-	u_int16_t		 len, optparamlen = 0;
-	u_int8_t		 i, op_type;
+	uint16_t		 len, optparamlen = 0;
+	uint8_t			 i, op_type;
 	int			 errs = 0, extlen = 0;
 	int			 mpcapa = 0;
 
@@ -1445,7 +1452,7 @@ session_open(struct peer *p)
 	/* graceful restart and End-of-RIB marker, RFC 4724 */
 	if (p->capa.ann.grestart.restart) {
 		int		rst = 0;
-		u_int16_t	hdr = 0;
+		uint16_t	hdr = 0;
 
 		for (i = 0; i < AID_MAX; i++) {
 			if (p->capa.neg.grestart.flags[i] & CAPA_GR_RESTARTING)
@@ -1463,7 +1470,7 @@ session_open(struct peer *p)
 
 	/* 4-bytes AS numbers, RFC6793 */
 	if (p->capa.ann.as4byte) {	/* 4 bytes data */
-		u_int32_t	nas;
+		uint32_t	nas;
 
 		nas = htonl(p->conf.local_as);
 		errs += session_capa_add(opb, CAPA_AS4BYTE, sizeof(nas));
@@ -1472,7 +1479,7 @@ session_open(struct peer *p)
 
 	/* advertisement of multiple paths, RFC7911 */
 	if (p->capa.ann.add_path[0]) {	/* variable */
-		u_int8_t	aplen;
+		uint8_t	aplen;
 
 		if (mpcapa)
 			aplen = 4 * mpcapa;
@@ -1532,7 +1539,7 @@ session_open(struct peer *p)
 
 	if (extlen) {
 		/* write RFC9072 extra header */
-		u_int16_t op_extlen = htons(optparamlen - 3);
+		uint16_t op_extlen = htons(optparamlen - 3);
 		op_type = OPT_PARAM_EXT_LEN;
 		errs += ibuf_add(buf->buf, &op_type, 1);
 		errs += ibuf_add(buf->buf, &op_extlen, 2);
@@ -1545,10 +1552,10 @@ session_open(struct peer *p)
 		optparamlen = ibuf_size(opb);
 		if (extlen) {
 			/* RFC9072: 2-byte extended length */
-			u_int16_t op_extlen = htons(optparamlen);
+			uint16_t op_extlen = htons(optparamlen);
 			errs += ibuf_add(buf->buf, &op_extlen, 2);
 		} else {
-			u_int8_t op_len = optparamlen;
+			uint8_t op_len = optparamlen;
 			errs += ibuf_add(buf->buf, &op_len, 1);
 		}
 		errs += ibuf_add(buf->buf, opb->buf, ibuf_size(opb));
@@ -1587,7 +1594,7 @@ session_keepalive(struct peer *p)
 }
 
 void
-session_update(u_int32_t peerid, void *data, size_t datalen)
+session_update(uint32_t peerid, void *data, size_t datalen)
 {
 	struct peer		*p;
 	struct bgp_msg		*buf;
@@ -1622,7 +1629,7 @@ session_update(u_int32_t peerid, void *data, size_t datalen)
 }
 
 void
-session_notification(struct peer *p, u_int8_t errcode, u_int8_t subcode,
+session_notification(struct peer *p, uint8_t errcode, uint8_t subcode,
     void *data, ssize_t datalen)
 {
 	struct bgp_msg		*buf;
@@ -1672,7 +1679,7 @@ session_notification(struct peer *p, u_int8_t errcode, u_int8_t subcode,
 int
 session_neighbor_rrefresh(struct peer *p)
 {
-	u_int8_t	i;
+	uint8_t	i;
 
 	if (!(p->capa.neg.refresh || p->capa.neg.enhanced_rr))
 		return (-1);
@@ -1686,12 +1693,12 @@ session_neighbor_rrefresh(struct peer *p)
 }
 
 void
-session_rrefresh(struct peer *p, u_int8_t aid, u_int8_t subtype)
+session_rrefresh(struct peer *p, uint8_t aid, uint8_t subtype)
 {
 	struct bgp_msg		*buf;
 	int			 errs = 0;
-	u_int16_t		 afi;
-	u_int8_t		 safi;
+	uint16_t		 afi;
+	uint8_t			 safi;
 
 	switch (subtype) {
 	case ROUTE_REFRESH_REQUEST:
@@ -1742,7 +1749,7 @@ session_rrefresh(struct peer *p, u_int8_t aid, u_int8_t subtype)
 int
 session_graceful_restart(struct peer *p)
 {
-	u_int8_t	i;
+	uint8_t	i;
 
 	timer_set(&p->timers, Timer_RestartTimeout,
 	    p->capa.neg.grestart.timeout);
@@ -1771,7 +1778,7 @@ session_graceful_restart(struct peer *p)
 int
 session_graceful_stop(struct peer *p)
 {
-	u_int8_t	i;
+	uint8_t	i;
 
 	for (i = 0; i < AID_MAX; i++) {
 		/*
@@ -1890,8 +1897,8 @@ session_process_msg(struct peer *p)
 	struct mrt	*mrt;
 	ssize_t		rpos, av, left;
 	int		processed = 0;
-	u_int16_t	msglen;
-	u_int8_t	msgtype;
+	uint16_t	msglen;
+	uint8_t		msgtype;
 
 	rpos = 0;
 	av = p->rbuf->wpos;
@@ -1969,11 +1976,11 @@ session_process_msg(struct peer *p)
 }
 
 int
-parse_header(struct peer *peer, u_char *data, u_int16_t *len, u_int8_t *type)
+parse_header(struct peer *peer, u_char *data, uint16_t *len, uint8_t *type)
 {
 	u_char			*p;
-	u_int16_t		 olen;
-	static const u_int8_t	 marker[MSGSIZE_HEADER_MARKER] = { 0xff, 0xff,
+	uint16_t		 olen;
+	static const uint8_t	 marker[MSGSIZE_HEADER_MARKER] = { 0xff, 0xff,
 				    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
 				    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
 
@@ -2068,12 +2075,12 @@ int
 parse_open(struct peer *peer)
 {
 	u_char		*p, *op_val;
-	u_int8_t	 version, rversion;
-	u_int16_t	 short_as, msglen;
-	u_int16_t	 holdtime, oholdtime, myholdtime;
-	u_int32_t	 as, bgpid;
-	u_int16_t	 optparamlen, extlen, plen, op_len;
-	u_int8_t	 op_type;
+	uint8_t		 version, rversion;
+	uint16_t	 short_as, msglen;
+	uint16_t	 holdtime, oholdtime, myholdtime;
+	uint32_t	 as, bgpid;
+	uint16_t	 optparamlen, extlen, plen, op_len;
+	uint8_t		 op_type;
 
 	p = peer->rbuf->rptr;
 	p += MSGSIZE_HEADER_MARKER;
@@ -2276,7 +2283,7 @@ int
 parse_update(struct peer *peer)
 {
 	u_char		*p;
-	u_int16_t	 datalen;
+	uint16_t	 datalen;
 
 	/*
 	 * we pass the message verbatim to the rde.
@@ -2302,8 +2309,8 @@ int
 parse_rrefresh(struct peer *peer)
 {
 	struct route_refresh rr;
-	u_int16_t afi, datalen;
-	u_int8_t aid, safi, subtype;
+	uint16_t afi, datalen;
+	uint8_t aid, safi, subtype;
 	u_char *p;
 
 	p = peer->rbuf->rptr;
@@ -2402,13 +2409,13 @@ int
 parse_notification(struct peer *peer)
 {
 	u_char		*p;
-	u_int16_t	 datalen;
-	u_int8_t	 errcode;
-	u_int8_t	 subcode;
-	u_int8_t	 capa_code;
-	u_int8_t	 capa_len;
+	uint16_t	 datalen;
+	uint8_t		 errcode;
+	uint8_t		 subcode;
+	uint8_t		 capa_code;
+	uint8_t		 capa_len;
 	size_t		 reason_len;
-	u_int8_t	 i;
+	uint8_t		 i;
 
 	/* just log */
 	p = peer->rbuf->rptr;
@@ -2546,19 +2553,19 @@ parse_notification(struct peer *peer)
 }
 
 int
-parse_capabilities(struct peer *peer, u_char *d, u_int16_t dlen, u_int32_t *as)
+parse_capabilities(struct peer *peer, u_char *d, uint16_t dlen, uint32_t *as)
 {
 	u_char		*capa_val;
-	u_int32_t	 remote_as;
-	u_int16_t	 len;
-	u_int16_t	 afi;
-	u_int16_t	 gr_header;
-	u_int8_t	 safi;
-	u_int8_t	 aid;
-	u_int8_t	 flags;
-	u_int8_t	 capa_code;
-	u_int8_t	 capa_len;
-	u_int8_t	 i;
+	uint32_t	 remote_as;
+	uint16_t	 len;
+	uint16_t	 afi;
+	uint16_t	 gr_header;
+	uint8_t		 safi;
+	uint8_t		 aid;
+	uint8_t		 flags;
+	uint8_t		 capa_code;
+	uint8_t		 capa_len;
+	uint8_t		 i;
 
 	len = dlen;
 	while (len > 0) {
@@ -2727,7 +2734,7 @@ parse_capabilities(struct peer *peer, u_char *d, u_int16_t dlen, u_int32_t *as)
 int
 capa_neg_calc(struct peer *p)
 {
-	u_int8_t	i, hasmp = 0;
+	uint8_t	i, hasmp = 0;
 
 	/* a capability is accepted only if both sides announced it */
 
@@ -2829,8 +2836,8 @@ session_dispatch_imsg(struct imsgbuf *ibuf, int idx, u_int *listener_cnt)
 	struct kif		*kif;
 	u_char			*data;
 	int			 n, fd, depend_ok, restricted;
-	u_int16_t		 t;
-	u_int8_t		 aid, errcode, subcode;
+	uint16_t		 t;
+	uint8_t			 aid, errcode, subcode;
 
 	while (ibuf) {
 		if ((n = imsg_get(ibuf, &imsg)) == -1)
@@ -3276,7 +3283,7 @@ getpeerbyip(struct bgpd_config *c, struct sockaddr *ip)
 {
 	struct bgpd_addr addr;
 	struct peer	*p, *newpeer, *loose = NULL;
-	u_int32_t	 id;
+	uint32_t	 id;
 
 	sa2addr(ip, &addr, NULL);
 
@@ -3321,7 +3328,7 @@ getpeerbyip(struct bgpd_config *c, struct sockaddr *ip)
 }
 
 struct peer *
-getpeerbyid(struct bgpd_config *c, u_int32_t peerid)
+getpeerbyid(struct bgpd_config *c, uint32_t peerid)
 {
 	static struct peer lookup;
 
@@ -3348,8 +3355,8 @@ peer_matched(struct peer *p, struct ctl_neighbor *n)
 }
 
 void
-session_template_clone(struct peer *p, struct sockaddr *ip, u_int32_t id,
-    u_int32_t as)
+session_template_clone(struct peer *p, struct sockaddr *ip, uint32_t id,
+    uint32_t as)
 {
 	struct bgpd_addr	remote_addr;
 
@@ -3448,14 +3455,14 @@ session_up(struct peer *p)
 }
 
 int
-imsg_ctl_parent(int type, u_int32_t peerid, pid_t pid, void *data,
-    u_int16_t datalen)
+imsg_ctl_parent(int type, uint32_t peerid, pid_t pid, void *data,
+    uint16_t datalen)
 {
 	return (imsg_compose(ibuf_main, type, peerid, pid, -1, data, datalen));
 }
 
 int
-imsg_ctl_rde(int type, pid_t pid, void *data, u_int16_t datalen)
+imsg_ctl_rde(int type, pid_t pid, void *data, uint16_t datalen)
 {
 	if (ibuf_rde_ctl == NULL) {
 		log_warnx("Can't send message %u to RDE, ctl pipe closed",
@@ -3470,7 +3477,7 @@ imsg_ctl_rde(int type, pid_t pid, void *data, u_int16_t datalen)
 }
 
 int
-imsg_rde(int type, uint32_t peerid, void *data, u_int16_t datalen)
+imsg_rde(int type, uint32_t peerid, void *data, uint16_t datalen)
 {
 	if (ibuf_rde == NULL) {
 		log_warnx("Can't send message %u to RDE, pipe closed", type);
@@ -3496,7 +3503,7 @@ session_demote(struct peer *p, int level)
 }
 
 void
-session_stop(struct peer *peer, u_int8_t subcode)
+session_stop(struct peer *peer, uint8_t subcode)
 {
 	char data[REASON_LEN];
 	size_t datalen;
